@@ -466,7 +466,7 @@ void KbfxConfigDlgLayout::KbfxExportFileAction()
 	<< endl;
 
 	/* write layout theme configuration file */
-	KConfig *layoutconfig = new KConfig ( KbfxExportLayoutRcDialogURL );
+	TDEConfig *layoutconfig = new TDEConfig ( KbfxExportLayoutRcDialogURL );
 
 	layoutconfig->setGroup ( "KbfxButton" );
 	layoutconfig->writeEntry ( "FadeTime", ConfigInit().m_fadeTime );
